==> cohesity_management_sdk-1.0.0.tar.gz: cohesity_management_sdk-1.0.0/cohesity_management_sdk/models/cluster_audit_log.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

import cohesity_management_sdk.models.tenant_details

class ClusterAuditLog(object):

    """Implementation of the 'Cluster Audit Log.' model.

    Specifies information about a single Cluster audit log.
    When an action (such as pausing a Protection Job) occurs, an audit log is
    generated that provides details about the action.

    Attributes:
        action (string): Specifies the action that caused the log to be
            generated.
        details (string): Specifies more information about the action.
        domain (string): Specifies the domain of the user who caused the
            action that generated the log.
        entity_id (string): Specifies the id of the entity (object) that the
            action is invoked on.
        entity_name (string): Specifies the entity (object) name that the
            action is invoked on. For example, if a Job called BackupEng is
            paused, this field returns BackupEng.
        entity_type (string): Specifies the type of the entity (object) that
            the action is invoked on. For example, if a Job called BackupEng
            is paused, this field returns 'Protection Job'.
        human_timestamp (string): Specifies the time when the log was
            generated. The time is specified using a human readable
            timestamp.
        impersonation (bool): Specifies if the log was generated during
            impersonation.
        new_record (string): Specifies the record after the action is
            invoked.
        original_tenant (TenantDetails): Specifies details about a tenant.
        previous_record (string): Specifies the record before the action is
            invoked.
        tenant (TenantDetails): Specifies details about a tenant.
        timestamp_usecs (long|int): Specifies the time when the log was
            generated. The time is specified using a Unix epoch Timestamp (in
            microseconds).
        user_name (string): Specifies the user who caused the action that
            generated the log.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "action":'action',
        "details":'details',
        "domain":'domain',
        "entity_id":'entityId',
        "entity_name":'entityName',
        "entity_type":'entityType',
        "human_timestamp":'humanTimestamp',
        "impersonation":'impersonation',
        "new_record":'newRecord',
        "original_tenant":'originalTenant',
        "previous_record":'previousRecord',
        "tenant":'tenant',
        "timestamp_usecs":'timestampUsecs',
        "user_name":'userName'
    }

    def __init__(self,
                 action=None,
                 details=None,
                 domain=None,
                 entity_id=None,
                 entity_name=None,
                 entity_type=None,
                 human_timestamp=None,
                 impersonation=None,
                 new_record=None,
                 original_tenant=None,
                 previous_record=None,
                 tenant=None,
                 timestamp_usecs=None,
                 user_name=None):
        """Constructor for the ClusterAuditLog class"""

        # Initialize members of the class
        self.action = action
        self.details = details
        self.domain = domain
        self.entity_id = entity_id
        self.entity_name = entity_name
        self.entity_type = entity_type
        self.human_timestamp = human_timestamp
        self.impersonation = impersonation
        self.new_record = new_record
        self.original_tenant = original_tenant
        self.previous_record = previous_record
        self.tenant = tenant
        self.timestamp_usecs = timestamp_usecs
        self.user_name = user_name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        action = dictionary.get('action')
        details = dictionary.get('details')
        domain = dictionary.get('domain')
        entity_id = dictionary.get('entityId')
        entity_name = dictionary.get('entityName')
        entity_type = dictionary.get('entityType')
        human_timestamp = dictionary.get('humanTimestamp')
        impersonation = dictionary.get('impersonation')
        new_record = dictionary.get('newRecord')
        original_tenant = cohesity_management_sdk.models.tenant_details.TenantDetails.from_dictionary(dictionary.get('originalTenant')) if dictionary.get('originalTenant') else None
        previous_record = dictionary.get('previousRecord')
        tenant = cohesity_management_sdk.models.tenant_details.TenantDetails.from_dictionary(dictionary.get('tenant')) if dictionary.get('tenant') else None
        timestamp_usecs = dictionary.get('timestampUsecs')
        user_name = dictionary.get('userName')

        # Return an object of this model
        return cls(action,
                   details,
                   domain,
                   entity_id,
                   entity_name,
                   entity_type,
                   human_timestamp,
                   impersonation,
                   new_record,
                   original_tenant,
                   previous_record,
                   tenant,
                   timestamp_usecs,
                   user_name)

==> cohesity_management_sdk-1.1.1.tar.gz: cohesity_management_sdk-1.1.1/cohesity_management_sdk/models/cluster_audit_log.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

import cohesity_management_sdk.models.tenant

class ClusterAuditLog(object):

    """Implementation of the 'ClusterAuditLog' model.

    Specifies information about a single Cluster audit log. When an action
    (such as pausing a Protection Job) occurs, an audit log is generated that
    provides details about the action.

    Attributes:
        action (string): Specifies the action that caused the log to be
            generated.
        details (string): Specifies more information about the action.
        domain (string): Specifies the domain of the user who caused the
            action that generated the log.
        entity_id (string): Specifies the id of the entity (object) that the
            action is invoked on.
        entity_name (string): Specifies the entity (object) name that the
            action is invoked on. For example, if a Job called BackupEng is
            paused, this field returns BackupEng.
        entity_type (string): Specifies the type of the entity (object) that
            the action is invoked on. For example, if a Job called BackupEng
            is paused, this field returns 'Protection Job'.
        human_timestamp (string): Specifies the time when the log was
            generated. The time is specified using a human readable
            timestamp.
        impersonation (bool): Specifies if the log was generated during
            impersonation.
        new_record (string): Specifies the record after the action is
            invoked.
        original_tenant (Tenant): Specifies details about a tenant.
        previous_record (string): Specifies the record before the action is
            invoked.
        tenant (Tenant): Specifies details about a tenant.
        timestamp_usecs (long|int): Specifies the time when the log was
            generated. The time is specified using a Unix epoch Timestamp (in
            microseconds).
        user_name (string): Specifies the user who caused the action that
            generated the log.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "action":'action',
        "details":'details',
        "domain":'domain',
        "entity_id":'entityId',
        "entity_name":'entityName',
        "entity_type":'entityType',
        "human_timestamp":'humanTimestamp',
        "impersonation":'impersonation',
        "new_record":'newRecord',
        "original_tenant":'originalTenant',
        "previous_record":'previousRecord',
        "tenant":'tenant',
        "timestamp_usecs":'timestampUsecs',
        "user_name":'userName'
    }

    def __init__(self,
                 action=None,
                 details=None,
                 domain=None,
                 entity_id=None,
                 entity_name=None,
                 entity_type=None,
                 human_timestamp=None,
                 impersonation=None,
                 new_record=None,
                 original_tenant=None,
                 previous_record=None,
                 tenant=None,
                 timestamp_usecs=None,
                 user_name=None):
        """Constructor for the ClusterAuditLog class"""

        # Initialize members of the class
        self.action = action
        self.details = details
        self.domain = domain
        self.entity_id = entity_id
        self.entity_name = entity_name
        self.entity_type = entity_type
        self.human_timestamp = human_timestamp
        self.impersonation = impersonation
        self.new_record = new_record
        self.original_tenant = original_tenant
        self.previous_record = previous_record
        self.tenant = tenant
        self.timestamp_usecs = timestamp_usecs
        self.user_name = user_name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        action = dictionary.get('action')
        details = dictionary.get('details')
        domain = dictionary.get('domain')
        entity_id = dictionary.get('entityId')
        entity_name = dictionary.get('entityName')
        entity_type = dictionary.get('entityType')
        human_timestamp = dictionary.get('humanTimestamp')
        impersonation = dictionary.get('impersonation')
        new_record = dictionary.get('newRecord')
        original_tenant = cohesity_management_sdk.models.tenant.Tenant.from_dictionary(dictionary.get('originalTenant')) if dictionary.get('originalTenant') else None
        previous_record = dictionary.get('previousRecord')
        tenant = cohesity_management_sdk.models.tenant.Tenant.from_dictionary(dictionary.get('tenant')) if dictionary.get('tenant') else None
        timestamp_usecs = dictionary.get('timestampUsecs')
        user_name = dictionary.get('userName')

        # Return an object of this model
        return cls(action,
                   details,
                   domain,
                   entity_id,
                   entity_name,
                   entity_type,
                   human_timestamp,
                   impersonation,
                   new_record,
                   original_tenant,
                   previous_record,
                   tenant,
                   timestamp_usecs,
                   user_name)
